@@ -1,6 +1,8 @@
-use mlua::{FromLua, IntoLua, Lua, Value, prelude::LuaError};
+use indexmap::IndexMap;
 use std::path::PathBuf;
 
+use mlua::{FromLua, IntoLua, Lua, LuaSerdeExt, Value, prelude::LuaError};
+
 use crate::{Plugin, error::Result, hooks::env_keys::EnvKey};
 
 #[derive(Debug, Clone)]
@@ -8,6 +10,7 @@ pub struct BackendExecEnvContext {
     pub tool: String,
     pub version: String,
     pub install_path: PathBuf,
+    pub options: IndexMap<String, String>,
 }
 
 #[derive(Debug)]
@@ -38,6 +41,7 @@ impl IntoLua for BackendExecEnvContext {
             "install_path",
             self.install_path.to_string_lossy().to_string(),
         )?;
+        table.set("options", lua.to_value(&self.options)?)?;
         Ok(Value::Table(table))
     }
 }
