@@ -422,27 +422,26 @@ pub fn install_artifact(
 
     // Use TarFormat for format detection
     // Check for explicit format option first, then fall back to file extension
-    let ext = if let Some(format_opt) = lookup_with_fallback(opts, "format") {
-        format_opt
+    let format = if let Some(format_opt) = lookup_with_fallback(opts, "format") {
+        file::TarFormat::from_ext(&format_opt)
     } else {
-        file_path
-            .extension()
-            .and_then(|s| s.to_str())
-            .unwrap_or("")
-            .to_string()
+        file::TarFormat::from_file_name(
+            &file_path.file_name().unwrap_or_default().to_string_lossy(),
+        )
     };
-    let format = file::TarFormat::from_ext(&ext);
 
     // Get file extension and detect format
     let file_name = file_path.file_name().unwrap().to_string_lossy();
 
-    // Check if it's a compressed binary (not a tar archive)
-    let is_compressed_binary =
-        !file_name.contains(".tar") && matches!(ext.as_str(), "gz" | "xz" | "bz2" | "zst");
-
-    if is_compressed_binary {
+    if !format.is_archive() && format != file::TarFormat::Raw {
         // Handle compressed single binary
+        let ext = Path::new(&*file_name)
+            .extension()
+            .and_then(|s| s.to_str())
+            .unwrap_or("")
+            .to_string();
         let decompressed_name = file_name.trim_end_matches(&format!(".{}", ext));
+
         // Determine the destination path with support for bin_path
         let dest = if let Some(bin_path_template) = lookup_with_fallback(opts, "bin_path") {
             let bin_path = template_string(&bin_path_template, tv);
@@ -457,13 +456,14 @@ pub fn install_artifact(
             install_path.join(cleaned_name)
         };
 
-        match ext.as_str() {
-            "gz" => file::un_gz(file_path, &dest)?,
-            "xz" => file::un_xz(file_path, &dest)?,
-            "bz2" => file::un_bz2(file_path, &dest)?,
-            "zst" => file::un_zst(file_path, &dest)?,
-            _ => unreachable!(),
-        }
+        file::untar(
+            file_path,
+            &dest,
+            &file::TarOptions {
+                pr,
+                ..file::TarOptions::new(format)
+            },
+        )?;
 
         file::make_executable(&dest)?;
     } else if format == file::TarFormat::Raw {
@@ -503,10 +503,9 @@ pub fn install_artifact(
             strip_components = Some(1);
         }
         let tar_opts = file::TarOptions {
-            format,
             strip_components: strip_components.unwrap_or(0),
             pr,
-            ..Default::default()
+            ..file::TarOptions::new(format)
         };
 
         // Extract with determined strip_components
@@ -517,21 +516,31 @@ pub fn install_artifact(
         let full_tool_name = tv.ba().tool_name.as_str();
         let tool_name = full_tool_name.rsplit('/').next().unwrap_or(full_tool_name);
 
-        // Determine search directory based on bin_path option (used by both bin= and rename_exe=)
-        let search_dir = if let Some(bin_path_template) = lookup_with_fallback(opts, "bin_path") {
-            let bin_path = template_string(&bin_path_template, tv);
-            install_path.join(&bin_path)
-        } else {
-            install_path.clone()
-        };
+        // Determine search directory based on bin_path option
+        let explicit_bin_path = lookup_with_fallback(opts, "bin_path")
+            .map(|t| install_path.join(template_string(&t, tv)));
 
         // Handle bin= option for archives (renames executable to specified name)
+        // bin= values are relative to install_path, so always use install_path or explicit bin_path
         if let Some(bin_name) = lookup_with_fallback(opts, "bin") {
-            rename_executable_in_dir(&search_dir, &bin_name, Some(tool_name))?;
+            let search_dir = explicit_bin_path.as_deref().unwrap_or(&install_path);
+            rename_executable_in_dir(search_dir, &bin_name, Some(tool_name))?;
         }
 
         // Handle rename_exe option for archives
+        // When bin_path is not explicitly set, auto-detect bin/ subdirectory to match
+        // the same logic used by discover_bin_paths() for PATH construction
         if let Some(rename_to) = lookup_with_fallback(opts, "rename_exe") {
+            let search_dir = if let Some(ref dir) = explicit_bin_path {
+                dir.clone()
+            } else {
+                let bin_dir = install_path.join("bin");
+                if bin_dir.is_dir() {
+                    bin_dir
+                } else {
+                    install_path.clone()
+                }
+            };
             rename_executable_in_dir(&search_dir, &rename_to, Some(tool_name))?;
         }
     }
