@@ -10,7 +10,7 @@ use crate::toolset::Toolset;
 use crate::ui::multi_progress_report::MultiProgressReport;
 use crate::{cli::args::ToolArg, config::Settings};
 use console::style;
-use eyre::Result;
+use eyre::{Result, bail};
 use tokio::sync::Semaphore;
 use tokio::task::JoinSet;
 
@@ -52,6 +52,11 @@ pub struct Lock {
 impl Lock {
     pub async fn run(self) -> Result<()> {
         let settings = Settings::get();
+        if settings.locked {
+            bail!(
+                "mise lock is disabled in --locked mode\nhint: Remove --locked or unset MISE_LOCKED=1"
+            );
+        }
         let config = Config::get().await?;
 
         let ts = config.get_toolset().await?;
