@@ -3,6 +3,7 @@ use std::collections::BTreeMap;
 use tabled::{Table, Tabled};
 
 use crate::config::Config;
+use crate::parallel;
 use crate::plugins::PluginType;
 use crate::plugins::core::CORE_PLUGINS;
 use crate::registry::full_to_url;
@@ -25,6 +26,11 @@ pub struct PluginsLs {
     #[clap(short, long, verbatim_doc_comment, conflicts_with = "all", hide = true)]
     pub core: bool,
 
+    /// Show plugins with available updates
+    /// Checks the remote for newer versions and only displays plugins that are outdated
+    #[clap(short, long, verbatim_doc_comment)]
+    pub outdated: bool,
+
     /// Show the git url for each plugin
     /// e.g.: https://github.com/mise-plugins/vfox-cmake.git
     #[clap(short, long, alias = "url", verbatim_doc_comment)]
@@ -74,7 +80,61 @@ impl PluginsLs {
             })
             .collect::<BTreeMap<_, _>>();
 
-        if self.urls || self.refs {
+        if self.outdated {
+            let installed: Vec<_> = plugins
+                .into_iter()
+                .filter(|(_, p)| p.is_installed())
+                .collect();
+            let results = parallel::parallel(installed, |(name, p)| async move {
+                tokio::task::spawn_blocking(move || {
+                    let local_sha = p.current_sha_short().unwrap_or_else(|e| {
+                        warn!("{name}: {e:?}");
+                        None
+                    });
+                    let remote_sha = p.remote_sha().unwrap_or_else(|e| {
+                        warn!("{name}: {e:?}");
+                        None
+                    });
+                    let remote_url = p.get_remote_url().unwrap_or_else(|e| {
+                        warn!("{name}: {e:?}");
+                        None
+                    });
+                    let abbrev_ref = p.current_abbrev_ref().unwrap_or_else(|e| {
+                        warn!("{name}: {e:?}");
+                        None
+                    });
+                    (name, local_sha, remote_sha, remote_url, abbrev_ref)
+                })
+                .await
+                .map_err(|e| eyre::eyre!(e))
+            })
+            .await?;
+            let mut data: Vec<_> = results
+                .into_iter()
+                .filter_map(|(name, local_sha, remote_sha, remote_url, abbrev_ref)| {
+                    let local_sha = local_sha?;
+                    let remote_sha = remote_sha?;
+                    if remote_sha.starts_with(&local_sha) {
+                        return None;
+                    }
+                    Some(OutdatedRow {
+                        plugin: name,
+                        url: remote_url.unwrap_or_default(),
+                        ref_: abbrev_ref.unwrap_or_default(),
+                        local: local_sha,
+                        remote: remote_sha.chars().take(7).collect(),
+                    })
+                })
+                .collect();
+            data.sort_by(|a, b| a.plugin.cmp(&b.plugin));
+            if data.is_empty() {
+                info!("All plugins are up to date");
+            } else {
+                let mut table = Table::new(data);
+                table::default_style(&mut table, false);
+                miseprintln!("{table}");
+            }
+        } else if self.urls || self.refs {
             let data = plugins
                 .into_iter()
                 .map(|(name, p)| {
@@ -125,6 +185,16 @@ struct Row {
     sha: String,
 }
 
+#[derive(Tabled)]
+#[tabled(rename_all = "PascalCase")]
+struct OutdatedRow {
+    plugin: String,
+    url: String,
+    ref_: String,
+    local: String,
+    remote: String,
+}
+
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
 
