@@ -517,14 +517,9 @@ fn trust_file_hash(path: &Path) -> eyre::Result<bool> {
 async fn filename_is_idiomatic(file_name: String) -> bool {
     for b in backend::list() {
         match b.idiomatic_filenames().await {
-            Ok(filenames) => {
-                if filenames.contains(&file_name) {
-                    return true;
-                }
-            }
-            Err(e) => {
-                debug!("idiomatic_filenames failed for {}: {:?}", b, e);
-            }
+            Ok(filenames) if filenames.contains(&file_name) => return true,
+            Err(e) => debug!("idiomatic_filenames failed for {}: {:?}", b, e),
+            _ => {}
         }
     }
     false
@@ -536,7 +531,6 @@ async fn detect_config_file_type(path: &Path) -> Option<ConfigFileType> {
         .and_then(|f| f.to_str())
         .unwrap_or("mise.toml")
     {
-        f if filename_is_idiomatic(f.to_string()).await => Some(ConfigFileType::IdiomaticVersion),
         f if env::MISE_OVERRIDE_TOOL_VERSIONS_FILENAMES
             .as_ref()
             .is_some_and(|o| o.contains(f)) =>
@@ -546,9 +540,10 @@ async fn detect_config_file_type(path: &Path) -> Option<ConfigFileType> {
         f if env::MISE_DEFAULT_TOOL_VERSIONS_FILENAME.as_str() == f => {
             Some(ConfigFileType::ToolVersions)
         }
-        f if f.ends_with(".toml") => Some(ConfigFileType::MiseToml),
         f if env::MISE_OVERRIDE_CONFIG_FILENAMES.contains(f) => Some(ConfigFileType::MiseToml),
         f if env::MISE_DEFAULT_CONFIG_FILENAME.as_str() == f => Some(ConfigFileType::MiseToml),
+        f if filename_is_idiomatic(f.to_string()).await => Some(ConfigFileType::IdiomaticVersion),
+        f if f.ends_with(".toml") => Some(ConfigFileType::MiseToml),
         _ => None,
     }
 }
