@@ -36,6 +36,7 @@ pub(crate) mod build_time;
 mod cache;
 mod cli;
 mod config;
+pub(crate) mod deps_graph;
 mod direnv;
 mod dirs;
 pub(crate) mod duration;
@@ -63,7 +64,6 @@ pub(crate) mod maplit;
 mod migrate;
 mod minisign;
 mod netrc;
-mod package_json;
 pub(crate) mod parallel;
 mod path;
 mod path_env;
