@@ -235,6 +235,14 @@ impl Plugin for AsdfPlugin {
         self.repo().current_sha_short().map(Some)
     }
 
+    fn remote_sha(&self) -> eyre::Result<Option<String>> {
+        if !self.is_installed() {
+            return Ok(None);
+        }
+        let branch = self.repo().current_branch()?;
+        self.repo().remote_sha(&branch)
+    }
+
     fn is_installed(&self) -> bool {
         self.plugin_path.exists()
     }
