@@ -2,6 +2,7 @@ mod bun;
 mod bundler;
 mod composer;
 mod custom;
+mod git_submodule;
 mod go;
 mod npm;
 mod pip;
@@ -14,6 +15,7 @@ pub use bun::BunPrepareProvider;
 pub use bundler::BundlerPrepareProvider;
 pub use composer::ComposerPrepareProvider;
 pub use custom::CustomPrepareProvider;
+pub use git_submodule::GitSubmodulePrepareProvider;
 pub use go::GoPrepareProvider;
 pub use npm::NpmPrepareProvider;
 pub use pip::PipPrepareProvider;
