@@ -15,7 +15,9 @@ use std::{collections::BTreeSet, sync::Arc};
 )]
 pub struct WatchFile {
     pub patterns: Vec<String>,
-    pub run: String,
+    #[serde(default)]
+    pub run: Option<String>,
+    pub task: Option<String>,
 }
 
 pub static MODIFIED_FILES: Mutex<Option<BTreeSet<PathBuf>>> = Mutex::new(None);
@@ -40,7 +42,18 @@ pub async fn execute_runs(config: &Arc<Config>, ts: &Toolset) {
                 continue;
             }
             Ok(files) => {
-                if let Err(e) = execute(config, ts, &root, &wf.run, files).await {
+                if wf.task.is_some() && wf.run.is_some() {
+                    warn!("watch_file hook has both run and task set, using task");
+                }
+                let result = if let Some(task_name) = &wf.task {
+                    execute_task(config, ts, &root, task_name, files).await
+                } else if let Some(run) = &wf.run {
+                    execute(config, ts, &root, run, files).await
+                } else {
+                    warn!("watch_file hook has neither run nor task set, skipping");
+                    continue;
+                };
+                if let Err(e) = result {
                     warn!("error executing watch_file hook: {e}");
                 }
             }
@@ -93,6 +106,43 @@ async fn execute(
     Ok(())
 }
 
+async fn execute_task(
+    config: &Arc<Config>,
+    ts: &Toolset,
+    root: &Path,
+    task_name: &str,
+    files: Vec<&PathBuf>,
+) -> Result<()> {
+    Settings::get().ensure_experimental("watch_file_hooks")?;
+    let modified_files_var = files
+        .iter()
+        .map(|f| f.to_string_lossy().replace(':', "\\:"))
+        .join(":");
+    let mise_bin = std::env::current_exe().unwrap_or_else(|_| PathBuf::from("mise"));
+
+    let mut env = ts.full_env(config).await?;
+    env.insert("MISE_WATCH_FILES_MODIFIED".to_string(), modified_files_var);
+    env.insert("MISE_NO_HOOKS".to_string(), "1".to_string());
+    if let Some(cwd) = &*dirs::CWD {
+        env.insert(
+            "MISE_ORIGINAL_CWD".to_string(),
+            cwd.to_string_lossy().to_string(),
+        );
+    }
+    env.insert(
+        "MISE_PROJECT_ROOT".to_string(),
+        root.to_string_lossy().to_string(),
+    );
+    cmd(
+        mise_bin,
+        ["--cd", &root.to_string_lossy(), "run", task_name],
+    )
+    .stdout_to_stderr()
+    .full_env(env)
+    .run()?;
+    Ok(())
+}
+
 fn has_matching_files<'a>(
     root: &Path,
     wf: &'a WatchFile,
@@ -138,28 +188,4 @@ pub fn glob(root: &Path, patterns: &[String]) -> Result<Vec<PathBuf>> {
         .into_iter()
         .flat_map(|paths| paths.filter_map(|p| p.ok()))
         .collect())
-
-    // let mut overrides = ignore::overrides::OverrideBuilder::new(root);
-    // for pattern in patterns {
-    //     overrides.add(&format!("./{pattern}"))?;
-    // }
-    // let files = Arc::new(Mutex::new(vec![]));
-    // ignore::WalkBuilder::new(root)
-    //     .overrides(overrides.build()?)
-    //     .standard_filters(false)
-    //     .follow_links(true)
-    //     .build_parallel()
-    //     .run(|| {
-    //         let files = files.clone();
-    //         Box::new(move |entry| {
-    //             if let Ok(entry) = entry {
-    //                 let mut files = files.lock().unwrap();
-    //                 files.push(entry.path().to_path_buf());
-    //             }
-    //             WalkState::Continue
-    //         })
-    //     });
-    //
-    // let files = files.lock().unwrap();
-    // Ok(files.to_vec())
 }
